@@ -11,11 +11,11 @@ Game::Planeshift::Info - A module to retrieve players' data on the main Planeshi
 
 =head1 VERSION
 
-Version 0.2b
+Version 0.3
 
 =cut
 
-our $VERSION = '0.2b';
+our $VERSION = '0.3';
 
 =head1 SYNOPSIS
 
@@ -329,7 +329,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$hours) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{most_active_players}->{$name} = $hours;
+					$data->{most_active_players}->{$name} = $hours if(defined($name) && defined($hours)) ;
 				}
 			}
 		}
@@ -365,7 +365,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$day_active,$hours_per_day) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{best_player_average}->{$name} = {day_active => $day_active,hours_per_day => $hours_per_day};
+					$data->{best_player_average}->{$name} = {day_active => $day_active,hours_per_day => $hours_per_day} if(defined($name) && defined($day_active) && defined($hours_per_day));
 				}
 			}
 		}
@@ -401,7 +401,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$advisor_points) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{best_advisors}->{$name} = $advisor_points;
+					$data->{best_advisors}->{$name} = $advisor_points  if(defined($name) && defined($advisor_points));
 				}
 			}
 		}
@@ -437,7 +437,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$duel_points) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{dueling_champs}->{$name} = $duel_points;
+					$data->{dueling_champs}->{$name} = $duel_points  if(defined($name) && defined($duel_points));
 				}
 			}
 		}
@@ -472,7 +472,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$str) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{stronger_players}->{$name} = $str;
+					$data->{stronger_players}->{$name} = $str  if(defined($name) && defined($str));
 				}
 			}
 		}
@@ -508,7 +508,7 @@ sub _parse_content
 				{
 					my $l = $1 ;
 					my ($name,$int) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{cleverer_players}->{$name} = $int;
+					$data->{cleverer_players}->{$name} = $int  if(defined($name) && defined($int));
 				}
 			}
 		}
@@ -536,7 +536,7 @@ sub is_online
 
 =head2 server_is_up
 
-	Return a boolean (0 or 1). True if the server is up.
+Return a boolean (0 or 1). True if the server is up.
 
 =cut
 
@@ -555,7 +555,7 @@ Translate a data (returned by the retrieve_info() method) to XML :
 The XML generated by this method on the data previously retrieve is :
 
 	<?xml version="1.0" encoding="iso-8859-1" standalone="yes"?>
-	<planeshift-info>
+	<Game-Planeshift-Info>
 		<server-status>
 			<time>Sun Feb 26 15:31:57 SGT 2006</time>
 			<total-online>45</total-online>
@@ -613,7 +613,7 @@ The XML generated by this method on the data previously retrieve is :
 			<player name="Brittany" points="263.33"/>
 			<player name="Kyixi" points="1008.00"/>
 		</dueling-champs>
-	</planeshift-info>
+	</Game-Planeshift-Info>
 
 
 =cut
@@ -621,7 +621,7 @@ The XML generated by this method on the data previously retrieve is :
 sub data2xml
 {
 	my ($self,$data) = @_;
-	my $xml = "<?xml version=\"1.0\" encoding=\"$self->{encoding}\" standalone=\"yes\"?>\n<planeshift-info>\n";
+	my $xml = "<?xml version=\"1.0\" encoding=\"$self->{encoding}\" standalone=\"yes\"?>\n<Game-Planeshift-Info>\n";
 	
 	$xml .= "\t<server-status>\n";
 	foreach (keys(%{$data->{server_status}}))
@@ -681,7 +681,7 @@ sub data2xml
 	}
 	$xml .= "\t</dueling-champs>\n";
 	
-	$xml .= "</planeshift-info>\n";
+	$xml .= "</Game-Planeshift-Info>\n";
 	
 	return $xml;
 }
@@ -693,8 +693,8 @@ Arnaud DUPUIS, C<< <dupuisarn at cpan.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-planeshift-info at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Planeshift-Info>.
+C<bug-Game-Planeshift-Info at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Game-Planeshift-Info>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -710,19 +710,19 @@ You can also look for information at:
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Planeshift-Info>
+L<http://annocpan.org/dist/Game-Planeshift-Info>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Planeshift-Info>
+L<http://cpanratings.perl.org/d/Game-Planeshift-Info>
 
 =item * RT: CPAN's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Planeshift-Info>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Game-Planeshift-Info>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Planeshift-Info>
+L<http://search.cpan.org/dist/Game-Planeshift-Info>
 
 =back
 
