@@ -5,7 +5,7 @@ use Game::Planeshift::Info ;
 use Data::Dumper;
 
 my $ps = Game::Planeshift::Info->new(
-	players => ['Baston', 'Ehasara', 'Narita', 'Setill', 'Soshise', 'Mardun', 'Caules', 'Javeroal']
+	players => ['Baston', 'Ehasara', 'Narita', 'Setill', 'Soshise', 'Mardun', 'Caules', 'Javeroal','Bodacher','Proglin','Eus','Sangwa','Anfa']
 ) ;
 
 # my $ps = Game::Planeshift::Info->new() ;
@@ -17,4 +17,4 @@ print Dumper($d);
 print "My coder is online !!!\n" if($ps->is_online('Baston')) ;
 print "My coder is not online :'(\n" unless($ps->is_online('Baston')) ;
 
-print $ps->data2xml($d) ;
\ No newline at end of file
+print $ps->data2xml($d) ;
